==> odoo_19.1a1.20251211.zip: odoo-19.1a1.post20251211/odoo/addons/im_livechat/static/src/core/web/discuss_app/sidebar/category_patch.js <==
import { DiscussSidebarCategory } from "@mail/discuss/core/public_web/discuss_app/sidebar/category";
import { DiscussSidebarChannel } from "@mail/discuss/core/public_web/discuss_app/sidebar/channel";
import { patch } from "@web/core/utils/patch";

/** @type {DiscussSidebarCategory} */
const DiscussSidebarCategoryPatch = {
    get actions() {
        const actions = super.actions;
        if (
            this.store.has_access_livechat &&
            this.category.livechat_channel_id &&
            this.category.is_open
        ) {
            actions.push({
                onSelect: () => {
                    if (this.category.livechat_channel_id.are_you_inside) {
                        this.category.livechat_channel_id.leave({ notify: false });
                    } else {
                        this.category.livechat_channel_id.join({ notify: false });
                    }
                },
                label: this.category.livechat_channel_id.are_you_inside
                    ? this.category.livechat_channel_id.leaveTitle
                    : this.category.livechat_channel_id.joinTitle,
                icon: this.category.livechat_channel_id.are_you_inside
                    ? "fa fa-sign-out fa-rotate-180 text-danger"
                    : "fa fa-sign-in text-success",
            });
        }
        return actions;
    },
};

/** @type {DiscussSidebarChannel} */
const DiscussSidebarChannelPatch = {
    get attClassContainer() {
        return {
            ...super.attClassContainer,
            "bg-100": this.channel.livechat_end_dt,
        };
    },
    get itemNameAttClass() {
        return {
            ...super.itemNameAttClass,
            "fst-italic text-muted fw-normal": this.channel.livechat_end_dt,
        };
    },
    get threadAvatarAttClass() {
        return {
            ...super.threadAvatarAttClass,
            "o-opacity-65": this.channel.livechat_end_dt,
        };
    },
};

patch(DiscussSidebarCategory.prototype, DiscussSidebarCategoryPatch);
patch(DiscussSidebarChannel.prototype, DiscussSidebarChannelPatch);

==> odoo_19.2a1.20260208.zip: odoo-19.2a1.post20260208/odoo/addons/im_livechat/static/src/core/web/discuss_app/sidebar/category_patch.js <==
import { DiscussSidebarCategory } from "@mail/discuss/core/public_web/discuss_app/sidebar/category";
import { DiscussSidebarChannel } from "@mail/discuss/core/public_web/discuss_app/sidebar/channel";
import { patch } from "@web/core/utils/patch";

/** @type {DiscussSidebarCategory} */
const DiscussSidebarCategoryPatch = {
    get actions() {
        const actions = super.actions;
        if (
            this.store.has_access_livechat &&
            this.category.livechat_channel_id &&
            this.category.is_open
        ) {
            actions.push({
                onSelect: () => {
                    if (this.category.livechat_channel_id.are_you_inside) {
                        this.category.livechat_channel_id.leave({ notify: false });
                    } else {
                        this.category.livechat_channel_id.join({ notify: false });
                    }
                },
                label: this.category.livechat_channel_id.are_you_inside
                    ? this.category.livechat_channel_id.leaveTitle
                    : this.category.livechat_channel_id.joinTitle,
                icon: this.category.livechat_channel_id.are_you_inside
                    ? "fa fa-sign-out fa-rotate-180 text-danger"
                    : "fa fa-sign-in text-success",
            });
        }
        return actions;
    },
    get isToggleFoldDisabled() {
        return this.category.eq(this.store.discuss.livechatLookingForHelpCategory)
            ? false
            : super.isToggleFoldDisabled;
    },
};

/** @type {DiscussSidebarChannel} */
const DiscussSidebarChannelPatch = {
    get attClassContainer() {
        return {
            ...super.attClassContainer,
            "bg-100": this.channel.livechat_end_dt,
        };
    },
    get itemNameAttClass() {
        return {
            ...super.itemNameAttClass,
            "fst-italic text-muted fw-normal": this.channel.livechat_end_dt,
        };
    },
    get threadAvatarAttClass() {
        return {
            ...super.threadAvatarAttClass,
            "o-opacity-65": this.channel.livechat_end_dt,
        };
    },
};

patch(DiscussSidebarCategory.prototype, DiscussSidebarCategoryPatch);
patch(DiscussSidebarChannel.prototype, DiscussSidebarChannelPatch);
